read method
The stored value, or null when nothing was stored yet (or the value
was deleted).
Throws an AuthException when the user cannot be authenticated and a StorageInvalidatedException when the value is permanently unrecoverable.
Implementation
Future<String?> read({PromptInfo? promptInfo}) =>
_plugin.read(name, promptInfo ?? defaultPromptInfo);